@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from django.conf.urls import url
+from django_six import re_path
 
 from django_file_upload import views as file_views
 
@@ -9,5 +9,5 @@ app_name = 'django_file_upload'
 
 
 urlpatterns = [
-    url(r'^upload$', file_views.file_upload, name='file_upload'),
+    re_path(r'^upload$', file_views.file_upload, name='file_upload'),
 ]
